==> haskell-network-multicast-0.2.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-4Sbhz5aJb3r8fTMnDGUXI0
key: network-multicast-0.2.0-4Sbhz5aJb3r8fTMnDGUXI0
license: PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
author: Audrey Tang <audreyt@audreyt.org>
exposed: True
indefinite: False
exposed-modules:
    Network.Multicast
abi: 4e7040d54943dcae38010d406dc1c26d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-4Sbhz5aJb3r8fTMnDGUXI0
depends:
    base-4.10.1.0 network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.2.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-A4cppeZtkgK3EAZDNz9YdM
key: network-multicast-0.2.0-A4cppeZtkgK3EAZDNz9YdM
license: PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
author: Audrey Tang <audreyt@audreyt.org>
exposed: True
indefinite: False
exposed-modules:
    Network.Multicast
abi: 42338a176bc8ae79dc08089435cc8305
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-A4cppeZtkgK3EAZDNz9YdM
depends:
    base-4.10.1.0 network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO=1e0aca6235e9d0fee0939ce314445bf3
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
